[![Git](https://git-scm.com/images/logo@2x.png)](https://git-scm.com/) --distributed-is-the-new-centralized
![](https://git-scm.com/images/dark-mode.svg)
  * [About](https://git-scm.com/about)
    * [Trademark](https://git-scm.com/about/trademark)
  * [Learn](https://git-scm.com/learn)
    * [Book](https://git-scm.com/book)
    * [Cheat Sheet](https://git-scm.com/cheat-sheet)
    * [Videos](https://git-scm.com/videos)
    * [External Links](https://git-scm.com/doc/ext)
  * [Tools](https://git-scm.com/tools)
    * [Command Line](https://git-scm.com/tools/command-line)
    * [GUIs](https://git-scm.com/tools/guis)
    * [Hosting](https://git-scm.com/tools/hosting)
  * [Reference](https://git-scm.com/docs)
  * [Install](https://git-scm.com/install/linux)
  * [Community](https://git-scm.com/community)


* * *
The entire **[Pro Git book](https://git-scm.com/book)** written by Scott Chacon and Ben Straub is available to [read online for free](https://git-scm.com/book). Dead tree versions are available on [Amazon.com](https://www.amazon.com/Pro-Git-Scott-Chacon/dp/1484200772?ie=UTF8&camp=1789&creative=9325&creativeASIN=1430218339&linkCode=as2&tag=git-sfconservancy-20).
## GIT TRADEMARK POLICY
### 1 Purpose
The Git Project is a member project of Software Freedom Conservancy ("Conservancy"). Conservancy holds rights in the Marks on behalf of the Git Project in accordance with its non- profit charitable mission.
Conservancy has adopted this Policy to protect the Marks (as defined below) and to make sure that the identity of Git software and its free and open source nature is clear to everyone. By using this Policy, the Git Project can spread the use of the Git software while making sure that the Marks are protected in a way that's consistent with U.S. trademark law ([U.S. Registration 4680534](https://tsdr.uspto.gov/#caseNumber=4680534&caseSearchType=US_APPLICATION&caseType=DEFAULT&searchType=statusSearch)). This Policy is written to allow all clear and appropriate use of the Marks while disapproving use of the Marks in ways that could confuse users as to where the software came from, or that implies an otherwise non- existent association with the Git Project. By adhering to this Policy, you help to promote to the public the freedom to use and develop the Git software.
Throughout this Policy, the word "Marks" refers to the following:
  * The literal mark "Git"
  * The logos and graphic marks displayed and available for download at <https://git-scm.com/community/logos>
  * The slogan "the stupid content tracker"


This Policy is only concerned with the Marks associated with the Git Project, and does not address any copyrights associated with the Git software.
### 2 Guidelines for using the Marks
#### 2.1 Trademark symbol on first mention
The first prominent mention of a Mark should be immediately followed by a symbol for, as applicable, a registered trademark (®) or an unregistered trademark (™). For example: "Git™".
This requirement is waived in all contexts where such marks are not required to protect the intellectual property rights associated with the Marks, such as email, online discussion, and academic papers. We encourage the use of the applicable symbols whenever possible, but recognize that many users will omit them in non-commercial and informal contexts.
You can use "Git and the Git logo are either registered trademarks or trademarks of Software Freedom Conservancy, Inc., corporate home of the Git Project, in the United States and/or other countries." when you need to mention "Git" in e.g. list of trademarks held by other people.
#### 2.2 Use of the Marks without written permission
You may use the Marks without prior written permission (subject to the other sections):
  1. To refer to the Git software in substantially unmodified form. "Substantially unmodified" means built from the source code provided by the Git Project, possibly with minor modifications including but not limited to: the enabling or disabling of certain features by default, translations into other languages, changes required for compatibility with a particular operating system distribution, or the inclusion of bug-fix patches.
  2. To identify the Git software as a distinct component of a software offering.
  3. To factually refer to the Git Project itself, its products, or its protocols.


In addition, you may use the Marks to refer to products, services, or communities outside of the Git software and Git Project without written permission in the following contexts:
  1. When referring to Git software that is not substantially unmodified, to say that such software is a "derivative of" or "based on" Git.
  2. When referring to a third-party software product and/or service that is interoperable with the Git software, in the format "[Product Name] for Git" -- provided that such use otherwise complies with the rest of this Policy.


We do not charge a fee for a license to use the Marks in these contexts. However, we do of course welcome donations. If you're interested in donating to the Git Project, care of Conservancy, visit <https://git-scm.com/sfc>. Conservancy is a United States 501(c)(3) public charity.
#### 2.3 Prohibited usages of the Marks
You may not use the Marks in the following ways:
  * In any way likely to cause confusion as to the identity of the Git Project, the provenance of its software, or the software's license.
  * In any way that indicates a greater degree of association between you and the Git Project than actually exists.
  * In any way that implies a designated successor to Git (e.g., "Git++" is not permitted).
  * In any way that indicates that Git favors one distribution, platform, product, etc. over another except where explicitly indicated in writing by Conservancy.
  * In any other way that dilutes or otherwise infringes upon the trademark rights of Conservancy and the Git Project in the Marks.
  * To refer to the Git software, modified by a third party to the point of inoperability with Git software in substantially unmodified form.


In addition, you may not use any of the Marks as a syllable in a new word or as part of a portmanteau (e.g., "Gitalicious", "Gitpedia") used as a mark for a third-party product or service. For the avoidance of doubt, this provision applies even to third-party marks that use the Marks as a syllable or as part of a portmanteau to refer to a product or service's use of Git code.
Please be aware that GitHub and GitLab are exceptions to this Policy because they are subject to explicit licensing arrangements that pre-date, and thus take precedence, over this Policy.
#### 2.4 Limitations to this Policy
This Policy does not confer any rights to use the trademarks "Software Freedom Conservancy," "Conservancy," or to use any other trademarks other than the Marks listed in Section 1. This Policy does not authorize you to act as an agent for Conservancy, enter into any agreement on behalf of or otherwise create any liability for the Git Project or Conservancy.
#### 2.5 Use of the Marks in merchandising
You may not create and/or sell merchandise bearing any of the Marks. If you are interested in using creating and/or selling merchandise bearing any of the Marks, please send proofs of your designs to us at TRADEMARK@SFCONSERVANCY.ORG.
### 3 Rights reserved by Conservancy
Conservancy reserves the sole right to:
  * Determine compliance with this Policy.
  * Modify this Policy in ways consistent with its mission of protecting the public.
  * Grant exceptions to this Policy, of any kind and for any reason whatsoever, other clauses notwithstanding.


### 4 Questions
This Policy is designed to keep the Marks safe in order to protect this software's reputation, earned by the contributions of the Git Project to the free and open source software community and to the public at large. If you see any use of the Marks anywhere that you think violates this Policy or otherwise goes against the spirit of the Git Project and Conservancy's mission, please bring it to Conservancy's attention by contacting us at TRADEMARK@SFCONSERVANCY.ORG.
If you have questions about using the Marks, or if you think you should be able to use the Marks for any purpose not allowed by this Policy and would like permission for that use, please contact Conservancy by emailing TRADEMARK@SFCONSERVANCY.ORG or by writing to Git Project c/o Software Freedom Conservancy, 137 Montague St. Ste 380, Brooklyn, NY 11201-3548.
[About this site](https://git-scm.com/site)
Patches, suggestions, and comments are welcome.
Git is a member of [Software Freedom Conservancy](https://git-scm.com/sfc)
